from setuptools import setup, find_packages 
setup( 
       name="pymoat",    # pypi project name
       version="0.1.0", 
       packages=find_packages(), 
       description="moat package",
       python_requires='>=3.6',
)